@@ -6,6 +6,7 @@ from prettytable import PrettyTable
 from e2e_cli.core.py_manager import Py_version_manager
 from e2e_cli.core.request_service import Request
 from e2e_cli.core.alias_service import AliasServices
+from e2e_cli.core.helper_service import Checks
 from e2e_cli.node.node import NodeCrud
 
 
@@ -31,8 +32,10 @@ class LBServices:
         if table.rowcount == 0:
             return "/"
         Py_version_manager.py_print(table)
-        node_choice = int(Py_version_manager.py_input("Enter the Node ID: "))
-        return node_choice
+        node_choice = Py_version_manager.py_input("Enter the Node ID: ")
+        while( not Checks.is_int(node_choice) or not int(node_choice) in node_list_dict): 
+            node_choice = Py_version_manager.py_input("Enter a valid Node ID: ")
+        return int(node_choice)
 
     def assign_nodes(self, nodes_assigned_to_lb, api_key, auth_token):
         node_class_object = NodeCrud(alias=self.alias,
@@ -50,6 +53,8 @@ class LBServices:
         Py_version_manager.py_print("Node name: ", node_list_dict[node_choice]["name"])
         Py_version_manager.py_print("Node ip: ", node_list_dict[node_choice]["public_ip_address"])
         node_port = Py_version_manager.py_input("Enter the Node Port: ")
+        while(not Checks.is_int(node_port)):
+            node_port = Py_version_manager.py_input("Enter the Node Port: ")
         nodes_assigned_to_lb.append(
             {"backend_name": node_list_dict[node_choice]["name"],
              "backend_ip": node_list_dict[node_choice]["private_ip_address"], "backend_port": node_port})
@@ -61,6 +66,8 @@ class LBServices:
             Py_version_manager.py_print("Node name: ", node_list_dict[node_choice]["name"])
             Py_version_manager.py_print("Node ip: ", node_list_dict[node_choice]["private_ip_address"])
             node_port = Py_version_manager.py_input("Enter the Node Port: ")
+            while(not Checks.is_int(node_port)):
+                node_port = Py_version_manager.py_input("Enter the Node Port: ")
             nodes_assigned_to_lb.append(
                 {"backend_name": node_list_dict[node_choice]["name"],
                  "backend_ip": node_list_dict[node_choice]["private_ip_address"], 
@@ -71,12 +78,16 @@ class LBServices:
     def classic_lb_creation(self, api_key, auth_token, nodes_assigned_to_lb, plan_assigned_to_lb):
         Py_version_manager.py_print("(Note: All the fields having a important ahead of them can't be skipped)")
         name_assigned_to_lb = Py_version_manager.py_input("Name of your lb(important): ")
-        Py_version_manager.py_print("  Load Balancing Property: ")
+        while(name_assigned_to_lb=="" or " " in name_assigned_to_lb):
+            name_assigned_to_lb = Py_version_manager.py_input("Name of your lb(important): ") 
+        Py_version_manager.py_print("Load Balancing Property: ")
         lb_balancing_property = {"1": "source",
                                  "2": "roundrobin"}
         Py_version_manager.py_print("1. Source IP Hash")
         Py_version_manager.py_print("2. Round Robin")
         lb_balancing_property_choice = Py_version_manager.py_input(": ")
+        while(not lb_balancing_property_choice in lb_balancing_property):
+            lb_balancing_property_choice = Py_version_manager.py_input("Please select from given choices only: ")
         balancing_property_assigned_to_lb = lb_balancing_property[lb_balancing_property_choice]
 
         nodes_assigned_to_lb = self.assign_nodes(nodes_assigned_to_lb, api_key, auth_token)
@@ -141,7 +152,9 @@ class LBServices:
             acl_conditions.append("path_end")
         elif acl_condition_choice == "8":
             acl_conditions.append("path_reg")
-        path = Py_version_manager.py_input("Enter value: ")
+        else:
+            self.acl_condition_path()
+        path = Py_version_manager.py_input("Enter the value to be matched for previous option : ")
         val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
         while val_choice.lower() == 'y':
             path = path + " " + Py_version_manager.py_input("Enter value")
@@ -167,6 +180,8 @@ class LBServices:
             acl_conditions.append("hdr_end(host) -i")
         elif acl_condition_choice == "4":
             acl_conditions.append("hdr_reg(host) -i")
+        else:
+            self.acl_condition_host()
         path = Py_version_manager.py_input("Enter value: ")
         val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
         while val_choice.lower() == 'y':
@@ -213,6 +228,8 @@ class LBServices:
         elif acl_condition_choice == "8":
             key = Py_version_manager.py_input("Key: ")
             acl_conditions.append("urlp_reg(" + key + ")")
+        else:
+            self.acl_condition_qpm()
         path = Py_version_manager.py_input("Enter value: ")
         val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
         while val_choice.lower() == 'y':
@@ -252,11 +269,15 @@ class LBServices:
             acl_conditions.append("CONNECT")
         elif acl_condition_choice == "8":
             acl_conditions.append("TRACE")
+        else: 
+            self.acl_condition_http()
         return acl_conditions
 
     def acl_condition_sip(self):
         acl_conditions = ["src"]
         path = Py_version_manager.py_input("Enter Source IP: ")
+        while(path=="" or " "in path):
+            path = Py_version_manager.py_input("Enter a valid Source IP: ")
         val_choice = Py_version_manager.py_input("Want to enter more values for the key(y/n): ")
         while val_choice.lower() == 'y':
             path = path + " " + Py_version_manager.py_input("Enter value")
@@ -299,6 +320,9 @@ class LBServices:
             condition_acl_list = self.acl_condition_sip()
             acl_instance["acl_condition"] = condition_acl_list[0]
             acl_instance["acl_matching_path"] = condition_acl_list[1]
+        else:
+            Py_version_manager.py_print("please select out of the given choices only")
+            self.set_acl_rules(rule_count)
         return acl_instance
 
     def acl_rules(self, acl_rules_assigned):
@@ -480,6 +504,9 @@ class LBServices:
                             backends_assigned_to_lb, plan_assigned_to_lb):
         Py_version_manager.py_print("(Note: All the fields having a important ahead of them can't be skipped)")
         name_assigned_to_lb = Py_version_manager.py_input("Name of your lb(important): ")
+        while(name_assigned_to_lb=="" or " " in name_assigned_to_lb):
+            name_assigned_to_lb = Py_version_manager.py_input("Name of your lb(important): ") 
+        Py_version_manager.py_print("Load Balancing Property: ")
         acl_rules_assigned_to_lb = self.acl_rules(acl_rules_assigned_to_lb)
         if not backends_assigned_to_lb:
             backends_assigned_to_lb = self.backends(api_key, auth_token, backends_assigned_to_lb, [])
@@ -533,8 +560,11 @@ class LBServices:
                     "message": api_key_credentials_object["message"]}
 
     def get_lb_by_id(self, lb_id):
-        lb_list = self.all_lb()["lb_api_response"]["data"]
-        found_dict = next((d for d in lb_list if d['id'] == int(lb_id)), None)
+        if(Checks.is_int(lb_id)):
+            lb_list = self.all_lb()["lb_api_response"]["data"]
+            found_dict = next((d for d in lb_list if d['id'] == int(lb_id)), None)
+        else:
+            found_dict=None
         return found_dict
 
     def add_lb(self):
@@ -547,6 +577,10 @@ class LBServices:
             Py_version_manager.py_print("1. Classic Load Balancer")
             Py_version_manager.py_print("2. Advanced Load Balancer")
             choice_of_lb = Py_version_manager.py_input(": ")
+            while (not Checks.is_int(choice_of_lb) or not 0<int(choice_of_lb)<=2):
+                Py_version_manager.py_print("please select out of the given choices only")
+                choice_of_lb = Py_version_manager.py_input(": ")
+            choice_of_lb=int(choice_of_lb)
             lb_plans = [
                 {
                     "ID": 1,
@@ -585,7 +619,11 @@ class LBServices:
                 table.add_row([plan_instance["ID"], plan_instance["Plan"],
                                plan_instance["Specs"], plan_instance["Price"]])
             Py_version_manager.py_print(table)
-            plan_choice = int(Py_version_manager.py_input(": "))
+            plan_choice = Py_version_manager.py_input(": ")
+            while (not Checks.is_int(plan_choice) or not 0<int(plan_choice)<=len(lb_plans)):
+                Py_version_manager.py_print("please select out of the given choices only")
+                plan_choice = Py_version_manager.py_input(": ")
+            plan_choice=int(plan_choice)
             plan_assigned_to_lb = lb_plans[plan_choice-1]["Plan"]
             if int(choice_of_lb) == 1:
                 payload = self.classic_lb_creation(api_key_credentials_object["api_credentials"]["api_key"],
@@ -610,10 +648,10 @@ class LBServices:
                 return {"lb_api_response": response_object.response.json(),
                         "message": api_key_credentials_object["message"]}
 
-    def delete_lb(self):
+    def delete_lb_sevice(self):
         lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
         all_lb_in_list = self.get_lb_by_id(lb_id)
-        while all_lb_in_list is None:
+        while (all_lb_in_list is None or not Checks.is_int(lb_id)):
             Py_version_manager.py_print("Please choose a valid load-balancer id: ")
             lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
             all_lb_in_list = self.get_lb_by_id(lb_id)
@@ -635,7 +673,7 @@ class LBServices:
                 return {"lb_api_response": response_object.response.json(),
                         "message": api_key_credentials_object["message"]}
         else:
-            return {"message": "Failure"}
+            return {"message": "Aborted"}
 
     def change_lb_name(self):
         lb_name = Py_version_manager.py_input(" Enter Load-Balancer Name: ")
@@ -743,7 +781,7 @@ class LBServices:
         else:
             lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
             all_lb_in_list = self.get_lb_by_id(lb_id)
-            while all_lb_in_list is None:
+            while(all_lb_in_list is None):
                 Py_version_manager.py_print("Please choose a valid load-balancer id: ")
                 lb_id = Py_version_manager.py_input("Enter the id of the lb: ")
                 all_lb_in_list = self.get_lb_by_id(lb_id)
@@ -780,3 +818,6 @@ class LBServices:
                 payload=json_payload)
                 return {"lb_api_response": response_obj.response.json(),
                         "message": api_key_credentials_object["message"]}
+
+            else:
+                return { "code" : "" ,"message": "Failure"}
\ No newline at end of file
