@@ -2,25 +2,25 @@ import argparse
 from functools import reduce
 
 from e2e_cli.commands_routing import CommandsRouting
-
+from e2e_cli.core.error_logs_service import ErrorLogs
 
 class Main:
     def __init__(self):
         pass
 
     def FormatUsage(self, parser, action):
-        format_string = "e2e_cli" + " " + action + " [-h]" + " {create,delete,list,edit/update} ... " + "alias"
+        format_string = "e2e_cli" + " alias"+ " " + action + " [-h]" + " {create,delete,list,edit/update} ... "
         parser.usage = format_string
 
     def FormatUsageCommand(self, parser, action, command):
-        format_string = "e2e_cli" + " " + action + " [-h] " + command + " alias"
+        format_string = "e2e_cli" + " alias"+ " " + action + " [-h] " + command
         subparser_list = list(parser._subparsers._group_actions[0].choices.keys())
         subparser_string = "{ " + reduce(lambda a, b: a + ", " + b, subparser_list) + " }"
-        format_string = "e2e_cli" + " " + action + " [-h]" + " " + subparser_string + " ... " + "alias=" + "<alias_name>"
+        format_string = "e2e_cli" + " alias=" + "<alias_name>"+ " " + action + " [-h]" + " " + subparser_string
         parser.usage = format_string
 
     def FormatUsageCommand(self, parser, action, command):
-        format_string = "e2e_cli" + " " + action + " [-h] " + command + " alias=" + "<alias_name>"
+        format_string = "e2e_cli" + " alias=" + "<alias_name>"+ " " + action + " [-h] " + command
         parser.usage = format_string
 
     def config(self, parser):
@@ -28,7 +28,6 @@ class Main:
         config_add_sub_parser = config_sub_parser.add_parser("add", help="To add api key and auth token")
         config_delete_sub_parser = config_sub_parser.add_parser("delete", help="To delete api key and auth token")
         config_view_sub_parser = config_sub_parser.add_parser("view", help="To view all alias and credentials")
-        parser.add_argument("alias", type=str, help="The name of your API access credentials")
         self.FormatUsageCommand(config_add_sub_parser, "config", "add")
         self.FormatUsageCommand(config_delete_sub_parser, "config", "delete")
         self.FormatUsageCommand(config_view_sub_parser, "config", "view")
@@ -39,7 +38,6 @@ class Main:
         node_delete_sub_parser = node_sub_parser.add_parser("delete", help="To delete a specific node")
         node_list_sub_parser = node_sub_parser.add_parser("list", help="To get a list of all nodes")
         node_get_sub_parser = node_sub_parser.add_parser("get", help="To get a list of all nodes")
-        parser.add_argument("alias", type=str, help="The name of your API access credentials")
         self.FormatUsageCommand(node_create_sub_parser, "node", "create")
         self.FormatUsageCommand(node_delete_sub_parser, "node", "delete")
         self.FormatUsageCommand(node_list_sub_parser, "node", "list")
@@ -51,7 +49,6 @@ class Main:
         node_delete_sub_parser = node_sub_parser.add_parser("delete", help="To delete a specific node")
         node_list_sub_parser = node_sub_parser.add_parser("list", help="To get a list of all nodes")
         node_edit_sub_parser = node_sub_parser.add_parser("edit", help="To get a list of all nodes")
-        parser.add_argument("alias", type=str, help="The name of your API access credentials")
         self.FormatUsageCommand(node_create_sub_parser, "node", "create")
         self.FormatUsageCommand(node_delete_sub_parser, "node", "delete")
         self.FormatUsageCommand(node_list_sub_parser, "node", "list")
@@ -62,7 +59,6 @@ class Main:
         bucket_create_sub_parser = bucket_sub_parser.add_parser("create", help="To create a new bucket")
         bucket_delete_sub_parser = bucket_sub_parser.add_parser("delete", help="To delete a specific bucket")
         bucket_delete_sub_parser = bucket_sub_parser.add_parser("list", help="To get a list of all buckets")
-        parser.add_argument("alias", type=str, help="The name of your API access credentials")
         self.FormatUsageCommand(bucket_create_sub_parser, "bucket", "create")
         self.FormatUsageCommand(bucket_delete_sub_parser, "bucket", "delete")
         self.FormatUsageCommand(bucket_delete_sub_parser, "bucket", "list")    
@@ -73,7 +69,6 @@ class Main:
         dbaas_create_sub_parser = dbaas_sub_parser.add_parser("create", help="To launch a new dbaas")
         dbaas_delete_sub_parser = dbaas_sub_parser.add_parser("delete", help="To delete a created dbaas")
         dbaas_list_sub_parser = dbaas_sub_parser.add_parser("list", help="To list all of your dbaas")
-        parser.add_argument("alias", type=str, help="The name of your API access credentials")
         self.FormatUsageCommand(dbaas_create_sub_parser, "dbaas", "create")
         self.FormatUsageCommand(dbaas_list_sub_parser, "dbaas", "list")
         self.FormatUsageCommand(dbaas_delete_sub_parser, "dbaas", "delete")
@@ -81,6 +76,7 @@ class Main:
         
 def run_main_class():
     parser = argparse.ArgumentParser(description="E2E CLI")
+    parser.add_argument("alias", type=str, help="The name of your API access credentials")
     sub_parsers = parser.add_subparsers(title="Commands", dest="command")
     config_parser = sub_parsers.add_parser("config", help="To add or delete api key and auth token")
     node_parser = sub_parsers.add_parser("node", help="To apply crud operations over Nodes")
@@ -101,5 +97,8 @@ def run_main_class():
     m.FormatUsage(dbaas_parser, "dbaas")
     
     args = parser.parse_args()
-    commands_route = CommandsRouting(args)
-    commands_route.route()
+    if(args.alias=="error_logs"):
+            ErrorLogs.recent_errors()
+    else:
+        commands_route = CommandsRouting(args)
+        commands_route.route()
