@@ -12,10 +12,16 @@ from e2e_cli.node.node_creation_service import NodeCreation
     
 class payload:
     def __init__(self, alias):
-        node_specifications=NodeCreation(alias).node_listing()
-       
-        self.image = node_specifications['image']
-        self.plan = node_specifications['plan']
+        Option=Py_version_manager.py_input("How would u like to proceed?? For Manual input type 'manual' ")
+
+        if(Option.lower()=="manual"):
+            self.image = input("please enter OS you require : ")
+            self.plan = input("please enter system requirements/plans : ")
+        else :
+            node_specifications=NodeCreation(alias).node_listing()
+            self.image = node_specifications['image']
+            self.plan = node_specifications['plan']
+
         if(node_specifications['location']=='Delhi'):
                 self.region='ncr'
         else:
